==> 5.5.9.1.tar.gz: dde-dock/plugins/dcc-dock-plugin/translations/dcc-dock-plugin_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>ModuleWidget</name>
    <message>
        <location filename="../module_widget.cpp" line="68"/>
        <source>Size</source>
        <translation>Velikost </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="69"/>
        <source>Multiple Displays</source>
        <translation>Více displejů </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="71"/>
        <source>Plugin Area</source>
        <translation>Oblast pluginu </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="72"/>
        <source>Select which icons appear in the Dock</source>
        <translation>Vyberte, které ikony se zobrazí v panelu</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="102"/>
        <location filename="../module_widget.cpp" line="107"/>
        <source>Fashion mode</source>
        <translation>Líbivý režim</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="103"/>
        <location filename="../module_widget.cpp" line="107"/>
        <source>Efficient mode</source>
        <translation>Nenáročný režim</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="105"/>
        <source>Mode</source>
        <translation>Režim </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="123"/>
        <location filename="../module_widget.cpp" line="130"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="124"/>
        <location filename="../module_widget.cpp" line="130"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="125"/>
        <location filename="../module_widget.cpp" line="130"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="126"/>
        <location filename="../module_widget.cpp" line="130"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="128"/>
        <source>Location</source>
        <translation>Umístění </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="145"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Keep shown</source>
        <translation>Ponechat zobrazený</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="146"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Keep hidden</source>
        <translation>Ponechat skrytý</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="147"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Smart hide</source>
        <translation>Chytré skrývání</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="149"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="170"/>
        <source>Small</source>
        <translation>Malý</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="170"/>
        <source>Large</source>
        <translation>Velký</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="201"/>
        <location filename="../module_widget.cpp" line="208"/>
        <source>On screen where the cursor is</source>
        <translation>Na obrazovce, kde je ukazovátko</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="202"/>
        <location filename="../module_widget.cpp" line="208"/>
        <source>Only on main screen</source>
        <translation>Pouze na hlavní obrazovce </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="206"/>
        <source>Show Dock</source>
        <translation>Zobrazit panel</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <location filename="../settings_module.cpp" line="68"/>
        <source>Dock</source>
        <translation>Panel</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
</TS>

==> 5.5.63.tar.gz: dde-dock/plugins/dcc-dock-plugin/translations/dcc-dock-plugin_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>ModuleWidget</name>
    <message>
        <location filename="../module_widget.cpp" line="86"/>
        <source>Size</source>
        <translation>Velikost </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="90"/>
        <source>Multiple Displays</source>
        <translation>Více displejů </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="82"/>
        <source>Plugin Area</source>
        <translation>Oblast pluginu </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="72"/>
        <source>Select which icons appear in the Dock</source>
        <translation>Vyberte, které ikony se zobrazí v panelu</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="114"/>
        <location filename="../module_widget.cpp" line="122"/>
        <source>Fashion mode</source>
        <translation>Líbivý režim</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="115"/>
        <location filename="../module_widget.cpp" line="122"/>
        <source>Efficient mode</source>
        <translation>Nenáročný režim</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="120"/>
        <source>Mode</source>
        <translation>Režim </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="142"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="143"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="144"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="145"/>
        <location filename="../module_widget.cpp" line="151"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="149"/>
        <source>Location</source>
        <translation>Umístění </translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="171"/>
        <location filename="../module_widget.cpp" line="179"/>
        <source>Keep shown</source>
        <translation>Ponechat zobrazený</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="172"/>
        <location filename="../module_widget.cpp" line="179"/>
        <source>Keep hidden</source>
        <translation>Ponechat skrytý</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="173"/>
        <location filename="../module_widget.cpp" line="179"/>
        <source>Smart hide</source>
        <translation>Chytré skrývání</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="177"/>
        <source>Status</source>
        <translation>Stav</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="201"/>
        <source>Small</source>
        <translation>Malý</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="201"/>
        <source>Large</source>
        <translation>Velký</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="235"/>
        <location filename="../module_widget.cpp" line="242"/>
        <source>On screen where the cursor is</source>
        <translation>Na obrazovce, na které se nachází ukazatel</translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="236"/>
        <location filename="../module_widget.cpp" line="242"/>
        <source>Only on main screen</source>
        <translation>Pouze na hlavní obrazovce </translation>
    </message>
    <message>
        <location filename="../module_widget.cpp" line="240"/>
        <source>Show Dock</source>
        <translation>Zobrazit panel</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <location filename="../settings_module.cpp" line="69"/>
        <location filename="../settings_module.cpp" line="107"/>
        <location filename="../settings_module.cpp" line="134"/>
        <source>Dock</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../settings_module.cpp" line="144"/>
        <source>Mode</source>
        <translation>Režim</translation>
    </message>
    <message>
        <location filename="../settings_module.cpp" line="145"/>
        <source>Location</source>
        <translation>Umístění </translation>
    </message>
    <message>
        <location filename="../settings_module.cpp" line="146"/>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <location filename="../settings_module.cpp" line="147"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../settings_module.cpp" line="148"/>
        <source>Show Dock</source>
        <translation>Zobrazit panel</translation>
    </message>
    <message>
        <location filename="../settings_module.cpp" line="149"/>
        <source>Plugin Area</source>
        <translation>Oblast pluginu </translation>
    </message>
</context>
</TS>
